@@ -13,13 +13,13 @@ pub enum TaskStatus {
     /// The task is queued and waiting for a free slot
     Queued,
     /// The task has been manually stashed. It won't be executed until it's manually enqueued
-    Stashed,
+    Stashed { enqueue_at: Option<DateTime<Local>> },
     /// The task is started and running
     Running,
     /// A previously running task has been paused
     Paused,
     /// Task finished. The actual result of the task is handled by the [TaskResult] enum.
-    Done,
+    Done(TaskResult),
     /// Used while the command of a task is edited (to prevent starting the task)
     Locked,
 }
@@ -53,7 +53,6 @@ pub struct Task {
     pub path: String,
     pub envs: HashMap<String, String>,
     pub group: String,
-    pub enqueue_at: Option<DateTime<Local>>,
     pub dependencies: Vec<usize>,
     pub label: Option<String>,
     pub status: TaskStatus,
@@ -61,7 +60,6 @@ pub struct Task {
     /// It's necessary, since we enter the `Locked` state during editing.
     /// However, we have to go back to the previous state after we finished editing.
     pub prev_status: TaskStatus,
-    pub result: Option<TaskResult>,
     pub start: Option<DateTime<Local>>,
     pub end: Option<DateTime<Local>>,
 }
@@ -74,7 +72,6 @@ impl Task {
         envs: HashMap<String, String>,
         group: String,
         starting_status: TaskStatus,
-        enqueue_at: Option<DateTime<Local>>,
         dependencies: Vec<usize>,
         label: Option<String>,
     ) -> Task {
@@ -87,12 +84,10 @@ impl Task {
             path,
             envs,
             group,
-            enqueue_at,
             dependencies,
             label,
             status: starting_status.clone(),
             prev_status: starting_status,
-            result: None,
             start: None,
             end: None,
         }
@@ -107,12 +102,10 @@ impl Task {
             path: task.path.clone(),
             envs: task.envs.clone(),
             group: "default".to_string(),
-            enqueue_at: None,
             dependencies: Vec::new(),
             label: task.label.clone(),
             status: TaskStatus::Queued,
             prev_status: TaskStatus::Queued,
-            result: None,
             start: None,
             end: None,
         }
@@ -125,17 +118,22 @@ impl Task {
 
     /// Whether the task's process finished.
     pub fn is_done(&self) -> bool {
-        self.status == TaskStatus::Done
+        matches!(self.status, TaskStatus::Done(_))
     }
 
     /// Check if the task errored. \
-    /// It either didn't run yet or finished successfully.
+    /// It either:
+    /// 1. Finished successfully
+    /// 2. Didn't finish yet.
     pub fn failed(&self) -> bool {
-        !matches!(self.result, None | Some(TaskResult::Success))
+        match &self.status {
+            TaskStatus::Done(result) => !matches!(result, TaskResult::Success),
+            _ => false,
+        }
     }
 
     pub fn is_queued(&self) -> bool {
-        self.status == TaskStatus::Queued || self.status == TaskStatus::Stashed
+        matches!(self.status, TaskStatus::Queued | TaskStatus::Stashed { .. })
     }
 
     /// Small convenience function to set the task's group to the default group.
